@@ -345,6 +345,12 @@ void FolderModel::invalidateFilterIfComplete()
     invalidateFilter();
 }
 
+void FolderModel::newFileMenuItemCreationStarted(const QUrl &url)
+{
+    Q_UNUSED(url);
+    setCreatingNewItems(true);
+}
+
 void FolderModel::newFileMenuItemCreated(const QUrl &url)
 {
     if (m_usedByContainment && !m_screenMapper->sharedDesktops()) {
@@ -353,6 +359,13 @@ void FolderModel::newFileMenuItemCreated(const QUrl &url)
         m_menuPosition = {};
         m_dropTargetPositionsCleanup->start();
     }
+    setCreatingNewItems(false);
+}
+
+void FolderModel::newFileMenuItemRejected(const QUrl &url)
+{
+    Q_UNUSED(url);
+    setCreatingNewItems(false);
 }
 
 QString FolderModel::url() const
@@ -1776,8 +1789,13 @@ void FolderModel::createActions()
 
     m_newMenu = new KNewFileMenu(this);
     m_newMenu->setModal(false);
+    // Disallow closing the popup when action to open the dialog is triggered
+    connect(m_newMenu, &KNewFileMenu::directoryCreationStarted, this, &FolderModel::newFileMenuItemCreationStarted);
+    connect(m_newMenu, &KNewFileMenu::fileCreationStarted, this, &FolderModel::newFileMenuItemCreationStarted);
     connect(m_newMenu, &KNewFileMenu::directoryCreated, this, &FolderModel::newFileMenuItemCreated);
     connect(m_newMenu, &KNewFileMenu::fileCreated, this, &FolderModel::newFileMenuItemCreated);
+    connect(m_newMenu, &KNewFileMenu::directoryCreationRejected, this, &FolderModel::newFileMenuItemRejected);
+    connect(m_newMenu, &KNewFileMenu::fileCreationRejected, this, &FolderModel::newFileMenuItemRejected);
 
     m_actionCollection.addAction(QStringLiteral("newMenu"), m_newMenu);
 
@@ -2199,6 +2217,7 @@ void FolderModel::setApplet(Plasma::Applet *applet)
                 setScreen(containment->screen());
                 connect(containment, &Plasma::Containment::screenChanged, this, &FolderModel::setScreen);
                 connect(containment, &Plasma::Containment::screenGeometryChanged, this, &FolderModel::screenGeometryChanged);
+                connect(containment, &Plasma::Containment::availableRelativeScreenRectChanged, this, &FolderModel::availableRelativeScreenRectChanged);
             }
         }
 
@@ -2217,6 +2236,19 @@ QRectF FolderModel::screenGeometry()
     return QRectF();
 }
 
+bool FolderModel::creatingNewItems() const
+{
+    return m_creatingNewItems;
+}
+
+void FolderModel::setCreatingNewItems(bool enabled)
+{
+    if (m_creatingNewItems != enabled) {
+        m_creatingNewItems = enabled;
+        Q_EMIT creatingNewItemsChanged();
+    }
+}
+
 bool FolderModel::showHiddenFiles() const
 {
     return m_showHiddenFiles;
