@@ -30,8 +30,8 @@ PlacesModel::~PlacesModel()
 QHash<int, QByteArray> PlacesModel::roleNames() const
 {
     QHash<int, QByteArray> roleNames = QSortFilterProxyModel::roleNames();
-    roleNames[Qt::DisplayRole] = "display";
-    roleNames[Qt::DecorationRole] = "decoration";
+    roleNames[Qt::DisplayRole] = QByteArrayLiteral("display");
+    roleNames[Qt::DecorationRole] = QByteArrayLiteral("decoration");
     return roleNames;
 }
 
@@ -95,3 +95,5 @@ bool PlacesModel::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParen
 
     return !m_sourceModel->isHidden(index);
 }
+
+#include "moc_placesmodel.cpp"
