@@ -8,11 +8,15 @@
 #include "kaccess.h"
 
 #include <KAboutData>
+#include <KCrash>
 #include <KLocalizedString>
+
 #include <QApplication>
 #include <QDebug>
 #include <QtGui/private/qtx11extras_p.h>
 
+#include <plasma_version.h>
+
 int main(int argc, char *argv[])
 {
     qunsetenv("SESSION_MANAGER");
@@ -33,13 +37,20 @@ int main(int argc, char *argv[])
     // we need an application object for QX11Info
     QApplication app(argc, argv);
 
-    KAboutData about(QStringLiteral("kaccess"), QString(), i18n("Accessibility"), {}, KAboutLicense::GPL_V2, i18n("(c) 2000, Matthias Hoelzer-Kluepfel"));
+    KAboutData about(QStringLiteral("kaccess"),
+                     i18n("Accessibility"),
+                     QStringLiteral(PLASMA_VERSION_STRING),
+                     {},
+                     KAboutLicense::GPL_V2,
+                     i18n("(c) 2000, Matthias Hoelzer-Kluepfel"));
 
     about.addAuthor(i18n("Matthias Hoelzer-Kluepfel"), i18n("Author"), QStringLiteral("hoelzer@kde.org"));
     about.setDesktopFileName(QStringLiteral("kaccess"));
     // set data as used for D-Bus by KAccessApp
     KAboutData::setApplicationData(about);
 
+    KCrash::initialize();
+
     KAccessApp acc;
     if (acc.isFailed()) {
         return 1;
