@@ -4,8 +4,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef ISO_CODES_H_
-#define ISO_CODES_H_
+#pragma once
 
 #include <QList>
 #include <QMap>
@@ -39,7 +38,7 @@ public:
      * @param isoCode Code for iso standard, i.e. "639", for convenience there's iso_* constants defined
      * @param isoCodesXmlDir the directory where ISO data are stored
      */
-    explicit IsoCodes(const QString &isoCode, const QString &isoCodesXmlDir = QStringLiteral("/usr/share/xml/iso-codes"));
+    explicit IsoCodes(const QString &isoCode);
     ~IsoCodes();
 
     /**
@@ -54,5 +53,3 @@ public:
 private:
     IsoCodesPrivate *const d;
 };
-
-#endif /* ISO_CODES_H_ */
