@@ -4,8 +4,7 @@
     SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef TASTENBRETT_H
-#define TASTENBRETT_H
+#pragma once
 
 #include <QString>
 
@@ -16,5 +15,3 @@ public:
     static bool exists();
     static void launch(const QString &model, const QString &layout, const QString &variant, const QString &options, const QString &title = QString());
 };
-
-#endif // TASTENBRETT_H
