@@ -227,7 +227,7 @@ LibinputTouchpad::LibinputTouchpad(Display *display, int deviceId)
     valueLoader(m_horizontalScrolling);
 }
 
-bool LibinputTouchpad::getConfig()
+bool LibinputTouchpad::load()
 {
     bool success = true;
 
@@ -269,7 +269,7 @@ bool LibinputTouchpad::getConfig()
     return success;
 }
 
-bool LibinputTouchpad::applyConfig()
+bool LibinputTouchpad::save()
 {
     QList<QString> msgs;
 
@@ -302,7 +302,7 @@ bool LibinputTouchpad::applyConfig()
     return success;
 }
 
-bool LibinputTouchpad::getDefaultConfig()
+bool LibinputTouchpad::defaults()
 {
     m_enabled.set(m_enabledDefault);
     m_tapToClick.set(m_tapToClickEnabledByDefault);
@@ -329,7 +329,7 @@ bool LibinputTouchpad::getDefaultConfig()
     return true;
 }
 
-bool LibinputTouchpad::isChangedConfig()
+bool LibinputTouchpad::isSaveNeeded() const
 {
     // clang-format off
     bool changed = m_enabled.changed() ||
@@ -358,11 +358,6 @@ bool LibinputTouchpad::isChangedConfig()
     return changed;
 }
 
-int LibinputTouchpad::touchpadOff()
-{
-    return m_enabled.val;
-}
-
 XcbAtom &LibinputTouchpad::touchpadOffAtom()
 {
     return *m_atoms[QLatin1String(LIBINPUT_PROP_SENDEVENTS_ENABLED)].get();
@@ -389,7 +384,7 @@ bool LibinputTouchpad::valueLoader(Prop<T> &prop)
     const T replyValue = valueLoaderPart<T>(reply);
     const T loadedValue = touchpadConfig.readEntry(QString(prop.name), replyValue);
     prop.old = replyValue;
-    prop.val = loadedValue;
+    prop.set(loadedValue);
 
     return true;
 }
